@@ -1,4 +1,5 @@
 from django import template
+from django.urls import reverse
 from django.utils.html import escape
 from django.utils.safestring import mark_safe
 
@@ -21,5 +22,13 @@ def format_change_data_field_value(field_value):
 
 @register.simple_tag
 def verbose_name(obj, fieldname):
-    if obj:
-        return obj._meta.get_field(fieldname).verbose_name
+    name = obj._meta.get_field(fieldname).verbose_name
+    return name.capitalize() if isinstance(name, str) else name
+
+
+@register.simple_tag
+def back_url(queryset, opts):
+    if len(queryset) == 1:
+        obj = queryset[0]
+        return reverse("admin:%s_%s_change" % (opts.app_label, opts.model_name), args=[obj.pk])
+    return reverse("admin:%s_%s_changelist" % (opts.app_label, opts.model_name))
